@@ -59,15 +59,15 @@ enum evdev_event_type {
 enum evdev_device_seat_capability {
 	EVDEV_DEVICE_POINTER = (1 << 0),
 	EVDEV_DEVICE_KEYBOARD = (1 << 1),
-	EVDEV_DEVICE_TOUCH = (1 << 2)
+	EVDEV_DEVICE_TOUCH = (1 << 2),
+	EVDEV_DEVICE_GESTURE = (1 << 5),
 };
 
 enum evdev_device_tags {
 	EVDEV_TAG_EXTERNAL_MOUSE = (1 << 0),
 	EVDEV_TAG_INTERNAL_TOUCHPAD = (1 << 1),
 	EVDEV_TAG_TRACKPOINT = (1 << 2),
-	EVDEV_TAG_TOUCHPAD_TRACKPOINT = (1 << 3),
-	EVDEV_TAG_KEYBOARD = (1 << 4),
+	EVDEV_TAG_KEYBOARD = (1 << 3),
 };
 
 enum evdev_middlebutton_state {
@@ -94,16 +94,19 @@ enum evdev_middlebutton_event {
 };
 
 enum evdev_device_model {
-	EVDEV_MODEL_DEFAULT,
-	EVDEV_MODEL_LENOVO_X230,
-	EVDEV_MODEL_CHROMEBOOK,
-	EVDEV_MODEL_SYSTEM76_BONOBO,
-	EVDEV_MODEL_SYSTEM76_GALAGO,
-	EVDEV_MODEL_SYSTEM76_KUDU,
-	EVDEV_MODEL_CLEVO_W740SU,
-	EVDEV_MODEL_APPLE_TOUCHPAD,
-	EVDEV_MODEL_WACOM_TOUCHPAD,
-	EVDEV_MODEL_ALPS_TOUCHPAD,
+	EVDEV_MODEL_DEFAULT = 0,
+	EVDEV_MODEL_LENOVO_X230 = (1 << 0),
+	EVDEV_MODEL_CHROMEBOOK = (1 << 1),
+	EVDEV_MODEL_SYSTEM76_BONOBO = (1 << 2),
+	EVDEV_MODEL_SYSTEM76_GALAGO = (1 << 3),
+	EVDEV_MODEL_SYSTEM76_KUDU = (1 << 4),
+	EVDEV_MODEL_CLEVO_W740SU = (1 << 5),
+	EVDEV_MODEL_APPLE_TOUCHPAD = (1 << 6),
+	EVDEV_MODEL_WACOM_TOUCHPAD = (1 << 7),
+	EVDEV_MODEL_ALPS_TOUCHPAD = (1 << 8),
+	EVDEV_MODEL_SYNAPTICS_SERIAL_TOUCHPAD = (1 << 9),
+	EVDEV_MODEL_JUMPING_SEMI_MT = (1 << 10),
+	EVDEV_MODEL_ELANTECH_TOUCHPAD = (1 << 11),
 };
 
 struct mt_slot {
@@ -163,6 +166,7 @@ struct evdev_device {
 		void (*change_scroll_method)(struct evdev_device *device);
 		bool button_scroll_active;
 		double threshold;
+		double direction_lock_threshold;
 		uint32_t direction;
 		struct normalized_coords buildup;
 
@@ -219,8 +223,9 @@ struct evdev_device {
 
 	int dpi; /* HW resolution */
 	struct ratelimit syn_drop_limit; /* ratelimit for SYN_DROPPED logging */
+	struct ratelimit nonpointer_rel_limit; /* ratelimit for REL_* events from non-pointer devices */
 
-	enum evdev_device_model model;
+	uint32_t model_flags;
 };
 
 #define EVDEV_UNHANDLED_DEVICE ((struct evdev_device *) 1)
@@ -277,7 +282,7 @@ evdev_device_create(struct libinput_seat *seat,
 
 int
 evdev_device_init_pointer_acceleration(struct evdev_device *device,
-				       accel_profile_func_t profile);
+				       struct motion_filter *filter);
 
 struct evdev_dispatch *
 evdev_touchpad_create(struct evdev_device *device);
@@ -358,24 +363,31 @@ evdev_notify_resumed_device(struct evdev_device *device);
 
 void
 evdev_keyboard_notify_key(struct evdev_device *device,
-			  uint32_t time,
+			  uint64_t time,
 			  int key,
 			  enum libinput_key_state state);
 
 void
 evdev_pointer_notify_button(struct evdev_device *device,
-			    uint32_t time,
+			    uint64_t time,
 			    int button,
 			    enum libinput_button_state state);
 void
 evdev_pointer_notify_physical_button(struct evdev_device *device,
-				     uint32_t time,
+				     uint64_t time,
 				     int button,
 				     enum libinput_button_state state);
 
 void
 evdev_init_natural_scroll(struct evdev_device *device);
 
+void
+evdev_notify_axis(struct evdev_device *device,
+		  uint64_t time,
+		  uint32_t axes,
+		  enum libinput_pointer_axis_source source,
+		  const struct normalized_coords *delta_in,
+		  const struct discrete_coords *discrete_in);
 void
 evdev_post_scroll(struct evdev_device *device,
 		  uint64_t time,
